==> blesta-5.10.2.zip: blesta/plugins/domains/language/pt_br/admin_main.php <==
<?php
/**
 * Admin Main
 *
 * @package blesta
 * @subpackage blesta.language.pt_br
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminMain.getmodulefields.auto_choose'] = '-- Escolha Automaticamente --';
$lang['AdminMain.edit.title_basic_options'] = 'Opções básicas';
$lang['AdminMain.edit.title_actions'] = 'Ações';
$lang['AdminMain.edit.title_domain_information'] = 'Informações de domínio';
$lang['AdminMain.edit.term_years'] = '%1$s Anos';
$lang['AdminMain.edit.term_year'] = '%1$s Ano';
$lang['AdminMain.edit.term_months'] = '%1$s Meses';
$lang['AdminMain.edit.term_month'] = '%1$s Mês';
$lang['AdminMain.edit.term_weeks'] = '%1$s Semanas';
$lang['AdminMain.edit.term_week'] = '%1$s Semana';
$lang['AdminMain.edit.term_days'] = '%1$s Dias';
$lang['AdminMain.edit.term_day'] = '%1$s Dia';
$lang['AdminMain.edit.text_date_canceled'] = 'Data de cancelamento:';
$lang['AdminMain.edit.text_date_suspended'] = 'Data da suspensão:';
$lang['AdminMain.edit.text_date_last_renewed'] = 'Data da última renovação:';
$lang['AdminMain.edit.text_never'] = 'Nunca';
$lang['AdminMain.edit.text_date_expires'] = 'Data de expiração:';
$lang['AdminMain.edit.text_date_renews'] = 'Data de renovação:';
$lang['AdminMain.edit.text_date_added'] = 'Data de criação:';
$lang['AdminMain.edit.text_status'] = 'Status:';
$lang['AdminMain.edit.text_years'] = 'Anos registrados:';
$lang['AdminMain.edit.text_registrar'] = 'Registrador:';
$lang['AdminMain.edit.text_domain'] = 'Domínio:';
$lang['AdminMain.edit.field_edit_service'] = 'Editar serviço';
$lang['AdminMain.edit.field_activate'] = 'Ativar';
$lang['AdminMain.edit.field_submit'] = 'Atualização';
$lang['AdminMain.edit.field_notify_order'] = 'Enviar e-mail de confirmação do pedido quando ativado';
$lang['AdminMain.edit.field_use_module'] = 'Usar módulo';
$lang['AdminMain.edit.field_module'] = 'Módulo de registro';
$lang['AdminMain.edit.field_client'] = 'Cliente';
$lang['AdminMain.edit.field_ns5'] = 'Servidor de nomes 5';
$lang['AdminMain.edit.field_ns4'] = 'Servidor de nomes 4';
$lang['AdminMain.edit.field_ns3'] = 'Servidor de nomes 3';
$lang['AdminMain.edit.field_ns2'] = 'Servidor de nomes 2';
$lang['AdminMain.edit.field_ns1'] = 'Servidor de nomes 1';
$lang['AdminMain.edit.field_auto_renewal'] = 'Habilitar a renovação automática';
$lang['AdminMain.edit.field_years'] = 'Anos';
$lang['AdminMain.edit.field_action'] = 'Ação';
$lang['AdminMain.edit.link_viewclient'] = 'Ver cliente';
$lang['AdminMain.edit.boxtitle_edit'] = 'Editar domínio: %1$s';
$lang['AdminMain.edit.boxtitle_client'] = 'Cliente #%1$s';
$lang['AdminMain.add_confirmation.discount'] = 'Desconto:';
$lang['AdminMain.add_confirmation.subtotal'] = 'Subtotal:';
$lang['AdminMain.add_confirmation.price'] = 'Preço';
$lang['AdminMain.add_confirmation.qty'] = 'Quantidade';
$lang['AdminMain.add_confirmation.description'] = 'Descrição';
$lang['AdminMain.add_confirmation.type_transfer'] = 'Transferência';
$lang['AdminMain.add_confirmation.type_register'] = 'Registro';
$lang['AdminMain.add_confirmation.field_edit'] = 'Editar';
$lang['AdminMain.add_confirmation.field_add'] = 'Adicionar domínio';
$lang['AdminMain.add_confirmation.field_update_coupon'] = 'Atualização';
$lang['AdminMain.add_confirmation.field_coupon_code'] = 'Código de cupom';
$lang['AdminMain.add_confirmation.field_price'] = 'Preço:';
$lang['AdminMain.add_confirmation.field_type'] = 'Tipo:';
$lang['AdminMain.add_confirmation.field_years'] = 'Anos:';
$lang['AdminMain.add_confirmation.field_domain'] = 'Domínio:';
$lang['AdminMain.add_confirmation.field_notify_order_false'] = 'Não';
$lang['AdminMain.add_confirmation.field_notify_order_true'] = 'Sim';
$lang['AdminMain.add_confirmation.field_notify_order'] = 'Enviar e-mail de confirmação do pedido:';
$lang['AdminMain.add_confirmation.field_module'] = 'Módulo de registro:';
$lang['AdminMain.add_confirmation.field_status'] = 'Status:';
$lang['AdminMain.add_confirmation.field_invoice_method_dont'] = 'Não faturar';
$lang['AdminMain.add_confirmation.field_invoice_method_append'] = 'Anexar à fatura %1$s';
$lang['AdminMain.add_confirmation.field_invoice_method_create'] = 'Criar nova fatura';
$lang['AdminMain.add_confirmation.field_invoice_method'] = 'Método de fatura:';
$lang['AdminMain.add.edit_package_pricing'] = 'Editar preços';
$lang['AdminMain.add.term_recurring'] = '%1$s @ %2$s (renova @ %3$s)';
$lang['AdminMain.add.term'] = '%1$s @ %2$s';
$lang['AdminMain.add.order_btn'] = 'Pedido selecionado';
$lang['AdminMain.add.term_years'] = '%1$s Anos';
$lang['AdminMain.add.term_year'] = '%1$s Ano';
$lang['AdminMain.add.term_months'] = '%1$s Meses';
$lang['AdminMain.add.term_month'] = '%1$s Mês';
$lang['AdminMain.add.term_weeks'] = '%1$s Semanas';
$lang['AdminMain.add.term_week'] = '%1$s Semana';
$lang['AdminMain.add.term_days'] = '%1$s Dias';
$lang['AdminMain.add.term_day'] = '%1$s Dia';
$lang['AdminMain.add.text_domain_unavailable'] = 'Não disponível';
$lang['AdminMain.add.text_domain_available'] = 'Disponível';
$lang['AdminMain.add.heading_options'] = 'Opções';
$lang['AdminMain.add.heading_status'] = 'Status';
$lang['AdminMain.add.heading_domain'] = 'Domínio';
$lang['AdminMain.add.title_registrar_options'] = 'Opções de registradores';
$lang['AdminMain.add.title_basic_options'] = 'Opções básicas';
$lang['AdminMain.add.title_search_results'] = 'Resultados da pesquisa';
$lang['AdminMain.add.field_notify_order'] = 'Enviar e-mail de confirmação do pedido quando ativado';
$lang['AdminMain.add.field_use_module'] = 'Provisione o domínio usando o módulo de registro quando ativado';
$lang['AdminMain.add.field_module'] = 'Módulo de registro';
$lang['AdminMain.add.field_status'] = 'Status';
$lang['AdminMain.add.field_years'] = 'Anos';
$lang['AdminMain.add.field_invoice_method_dont'] = 'Não faturar';
$lang['AdminMain.add.field_invoice_method_append'] = 'Anexar à fatura existente';
$lang['AdminMain.add.field_invoice_method_create'] = 'Criar nova fatura';
$lang['AdminMain.add.field_invoice_method'] = 'Método de fatura';
$lang['AdminMain.add.field_submit'] = 'Continuar';
$lang['AdminMain.add.field_lookup'] = 'Verificar disponibilidade';
$lang['AdminMain.add.field_add'] = 'Adicionar domínio';
$lang['AdminMain.add.field_register'] = 'Registro';
$lang['AdminMain.add.field_transfer'] = 'Transferência';
$lang['AdminMain.add.link_viewclient'] = 'Ver cliente';
$lang['AdminMain.add.boxtitle_add'] = 'Adicionar domínio: %1$s';
$lang['AdminMain.add.boxtitle_client'] = 'Cliente #%1$s';
$lang['AdminMain.index.unparent'] = 'Preço de reposição e sem pais';
$lang['AdminMain.!error.unsupported_domain'] = 'O nome de domínio não é compatível.';
$lang['AdminMain.!success.service_edited'] = 'O domínio foi atualizado com sucesso!';
$lang['AdminMain.!success.domain_add'] = 'O domínio foi adicionado com sucesso!';
$lang['AdminMain.!success.domain_transfer'] = 'O domínio foi transferido com sucesso!';
$lang['AdminMain.!success.domain_register'] = 'O domínio foi registrado com sucesso!';
$lang['AdminMain.!success.domains_unparented'] = 'Os domínios selecionados foram removidos de seus serviços principais e o preço foi redefinido com sucesso!';
$lang['AdminMain.getfilters.field_service_meta'] = 'Nome de domínio';
$lang['AdminMain.getfilters.field_package_name'] = 'TLD';
$lang['AdminMain.getfilters.any'] = 'Qualquer';
$lang['AdminMain.domains.action.field_client'] = 'Cliente';
$lang['AdminMain.domains.action.field_nameservers'] = 'Servidores de nomes';
$lang['AdminMain.domains.action.field_years'] = 'Anos';
$lang['AdminMain.index.field_actionsubmit'] = 'Enviar';
$lang['AdminMain.index.domain_push_to_client'] = 'Enviar para o cliente';
$lang['AdminMain.index.update_nameservers'] = 'Atualizar servidores de nomes';
$lang['AdminMain.index.domain_renewal'] = 'Renovar domínio';
$lang['AdminMain.index.change_auto_renewal'] = 'Alterar renovação automática';
$lang['AdminMain.index.text_off'] = 'Desligado';
$lang['AdminMain.index.text_on'] = 'Em';
$lang['AdminMain.index.text_never'] = 'Nunca';
$lang['AdminMain.index.no_results'] = 'Não há serviços com esse status.';
$lang['AdminMain.index.confirm_delete'] = 'Tem certeza de que deseja excluir esse serviço?';
$lang['AdminMain.index.option_delete'] = 'Excluir';
$lang['AdminMain.index.option_manage'] = 'Gerenciar';
$lang['AdminMain.index.option_parent'] = 'Pais';
$lang['AdminMain.index.recurring_term'] = '%1$s %2$s @ %3$s';
$lang['AdminMain.index.categorylink_newservice'] = 'Novo domínio';
$lang['AdminMain.index.category_canceled'] = 'Cancelado';
$lang['AdminMain.index.category_suspended'] = 'Suspenso';
$lang['AdminMain.index.category_pending'] = 'Pendente';
$lang['AdminMain.index.category_active'] = 'Ativo';
$lang['AdminMain.index.heading_options'] = 'Opções';
$lang['AdminMain.index.heading_datecanceled'] = 'Data do cancelamento';
$lang['AdminMain.index.heading_datesuspended'] = 'Data da suspensão';
$lang['AdminMain.index.heading_dateexpires'] = 'Data de expiração';
$lang['AdminMain.index.heading_daterenews'] = 'Data de renovação';
$lang['AdminMain.index.heading_datecreated'] = 'Data de criação';
$lang['AdminMain.index.heading_term'] = 'Prazo';
$lang['AdminMain.index.heading_domain'] = 'Domínio';
$lang['AdminMain.index.heading_status'] = 'Status';
$lang['AdminMain.index.heading_addons'] = 'Complementos';
$lang['AdminMain.index.boxtitle_domains'] = 'Domínios';
$lang['AdminMain.index.page_title'] = 'Cliente #%1$s Domínios';
$lang['AdminMain.!success.domains_pushed'] = 'Os domínios selecionados foram enviados com sucesso para o novo cliente.';
$lang['AdminMain.!success.update_nameservers'] = 'Os servidores de nomes de domínio foram atualizados!';
$lang['AdminMain.!success.domain_renewal'] = 'O domínio foi renovado!';
$lang['AdminMain.!success.change_auto_renewal'] = 'A renovação automática do domínio foi atualizada!';
$lang['AdminMain.edit.text_registration_date'] = 'Data de registro:';
$lang['AdminMain.index.text_date_added'] = 'Data de adição:';
$lang['AdminMain.index.heading_dateregistration'] = 'Data de registro';
$lang['AdminMain.index.heading_registrar'] = 'Registrador';
$lang['AdminMain.!success.domain_registrar_updated'] = 'O registrador de domínios foi atualizado!';

==> blesta-5.11.4.zip: blesta/plugins/domains/language/pt_br/admin_main.php <==
<?php
/**
 * Admin Main
 *
 * @package blesta
 * @subpackage blesta.language.pt_br
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminMain.getmodulefields.auto_choose'] = '-- Escolha Automaticamente --';
$lang['AdminMain.edit.title_basic_options'] = 'Opções básicas';
$lang['AdminMain.edit.title_actions'] = 'Ações';
$lang['AdminMain.edit.title_domain_information'] = 'Informações de domínio';
$lang['AdminMain.edit.term_years'] = '%1$s Anos';
$lang['AdminMain.edit.term_year'] = '%1$s Ano';
$lang['AdminMain.edit.term_months'] = '%1$s Meses';
$lang['AdminMain.edit.term_month'] = '%1$s Mês';
$lang['AdminMain.edit.term_weeks'] = '%1$s Semanas';
$lang['AdminMain.edit.term_week'] = '%1$s Semana';
$lang['AdminMain.edit.term_days'] = '%1$s Dias';
$lang['AdminMain.edit.term_day'] = '%1$s Dia';
$lang['AdminMain.edit.text_date_canceled'] = 'Data de cancelamento:';
$lang['AdminMain.edit.text_date_suspended'] = 'Data da suspensão:';
$lang['AdminMain.edit.text_date_last_renewed'] = 'Data da última renovação:';
$lang['AdminMain.edit.text_never'] = 'Nunca';
$lang['AdminMain.edit.text_date_expires'] = 'Data de expiração:';
$lang['AdminMain.edit.text_date_renews'] = 'Data de renovação:';
$lang['AdminMain.edit.text_date_added'] = 'Data de criação:';
$lang['AdminMain.edit.text_status'] = 'Status:';
$lang['AdminMain.edit.text_years'] = 'Anos registrados:';
$lang['AdminMain.edit.text_registrar'] = 'Registrador:';
$lang['AdminMain.edit.text_domain'] = 'Domínio:';
$lang['AdminMain.edit.field_edit_service'] = 'Editar serviço';
$lang['AdminMain.edit.field_activate'] = 'Ativar';
$lang['AdminMain.edit.field_submit'] = 'Atualização';
$lang['AdminMain.edit.field_notify_order'] = 'Enviar e-mail de confirmação do pedido quando ativado';
$lang['AdminMain.edit.field_use_module'] = 'Usar módulo';
$lang['AdminMain.edit.field_module'] = 'Módulo de registro';
$lang['AdminMain.edit.field_client'] = 'Cliente';
$lang['AdminMain.edit.field_ns5'] = 'Servidor de nomes 5';
$lang['AdminMain.edit.field_ns4'] = 'Servidor de nomes 4';
$lang['AdminMain.edit.field_ns3'] = 'Servidor de nomes 3';
$lang['AdminMain.edit.field_ns2'] = 'Servidor de nomes 2';
$lang['AdminMain.edit.field_ns1'] = 'Servidor de nomes 1';
$lang['AdminMain.edit.field_auto_renewal'] = 'Habilitar a renovação automática';
$lang['AdminMain.edit.field_years'] = 'Anos';
$lang['AdminMain.edit.field_action'] = 'Ação';
$lang['AdminMain.edit.link_viewclient'] = 'Ver cliente';
$lang['AdminMain.edit.boxtitle_edit'] = 'Editar domínio: %1$s';
$lang['AdminMain.edit.boxtitle_client'] = 'Cliente #%1$s';
$lang['AdminMain.add_confirmation.discount'] = 'Desconto:';
$lang['AdminMain.add_confirmation.subtotal'] = 'Subtotal:';
$lang['AdminMain.add_confirmation.price'] = 'Preço';
$lang['AdminMain.add_confirmation.qty'] = 'Quantidade';
$lang['AdminMain.add_confirmation.description'] = 'Descrição';
$lang['AdminMain.add_confirmation.type_transfer'] = 'Transferência';
$lang['AdminMain.add_confirmation.type_register'] = 'Registro';
$lang['AdminMain.add_confirmation.field_edit'] = 'Editar';
$lang['AdminMain.add_confirmation.field_add'] = 'Adicionar domínio';
$lang['AdminMain.add_confirmation.field_update_coupon'] = 'Atualização';
$lang['AdminMain.add_confirmation.field_coupon_code'] = 'Código de cupom';
$lang['AdminMain.add_confirmation.field_price'] = 'Preço:';
$lang['AdminMain.add_confirmation.field_type'] = 'Tipo:';
$lang['AdminMain.add_confirmation.field_years'] = 'Anos:';
$lang['AdminMain.add_confirmation.field_domain'] = 'Domínio:';
$lang['AdminMain.add_confirmation.field_notify_order_false'] = 'Não';
$lang['AdminMain.add_confirmation.field_notify_order_true'] = 'Sim';
$lang['AdminMain.add_confirmation.field_notify_order'] = 'Enviar e-mail de confirmação do pedido:';
$lang['AdminMain.add_confirmation.field_module'] = 'Módulo de registro:';
$lang['AdminMain.add_confirmation.field_status'] = 'Status:';
$lang['AdminMain.add_confirmation.field_invoice_method_dont'] = 'Não faturar';
$lang['AdminMain.add_confirmation.field_invoice_method_append'] = 'Anexar à fatura %1$s';
$lang['AdminMain.add_confirmation.field_invoice_method_create'] = 'Criar nova fatura';
$lang['AdminMain.add_confirmation.field_invoice_method'] = 'Método de fatura:';
$lang['AdminMain.add.edit_package_pricing'] = 'Editar preços';
$lang['AdminMain.add.term_recurring'] = '%1$s @ %2$s (renova @ %3$s)';
$lang['AdminMain.add.term'] = '%1$s @ %2$s';
$lang['AdminMain.add.order_btn'] = 'Pedido selecionado';
$lang['AdminMain.add.term_years'] = '%1$s Anos';
$lang['AdminMain.add.term_year'] = '%1$s Ano';
$lang['AdminMain.add.term_months'] = '%1$s Meses';
$lang['AdminMain.add.term_month'] = '%1$s Mês';
$lang['AdminMain.add.term_weeks'] = '%1$s Semanas';
$lang['AdminMain.add.term_week'] = '%1$s Semana';
$lang['AdminMain.add.term_days'] = '%1$s Dias';
$lang['AdminMain.add.term_day'] = '%1$s Dia';
$lang['AdminMain.add.text_domain_unavailable'] = 'Não disponível';
$lang['AdminMain.add.text_domain_available'] = 'Disponível';
$lang['AdminMain.add.heading_options'] = 'Opções';
$lang['AdminMain.add.heading_status'] = 'Status';
$lang['AdminMain.add.heading_domain'] = 'Domínio';
$lang['AdminMain.add.title_registrar_options'] = 'Opções de registradores';
$lang['AdminMain.add.title_basic_options'] = 'Opções básicas';
$lang['AdminMain.add.title_search_results'] = 'Resultados da pesquisa';
$lang['AdminMain.add.field_notify_order'] = 'Enviar e-mail de confirmação do pedido quando ativado';
$lang['AdminMain.add.field_use_module'] = 'Provisione o domínio usando o módulo de registro quando ativado';
$lang['AdminMain.add.field_module'] = 'Módulo de registro';
$lang['AdminMain.add.field_status'] = 'Status';
$lang['AdminMain.add.field_years'] = 'Anos';
$lang['AdminMain.add.field_invoice_method_dont'] = 'Não faturar';
$lang['AdminMain.add.field_invoice_method_append'] = 'Anexar à fatura existente';
$lang['AdminMain.add.field_invoice_method_create'] = 'Criar nova fatura';
$lang['AdminMain.add.field_invoice_method'] = 'Método de fatura';
$lang['AdminMain.add.field_submit'] = 'Continuar';
$lang['AdminMain.add.field_lookup'] = 'Verificar disponibilidade';
$lang['AdminMain.add.field_add'] = 'Adicionar domínio';
$lang['AdminMain.add.field_register'] = 'Registro';
$lang['AdminMain.add.field_transfer'] = 'Transferência';
$lang['AdminMain.add.link_viewclient'] = 'Ver cliente';
$lang['AdminMain.add.boxtitle_add'] = 'Adicionar domínio: %1$s';
$lang['AdminMain.add.boxtitle_client'] = 'Cliente #%1$s';
$lang['AdminMain.index.unparent'] = 'Preço de reposição e sem pais';
$lang['AdminMain.!error.unsupported_domain'] = 'O nome de domínio não é compatível.';
$lang['AdminMain.!success.service_edited'] = 'O domínio foi atualizado com sucesso!';
$lang['AdminMain.!success.domain_add'] = 'O domínio foi adicionado com sucesso!';
$lang['AdminMain.!success.domain_transfer'] = 'O domínio foi transferido com sucesso!';
$lang['AdminMain.!success.domain_register'] = 'O domínio foi registrado com sucesso!';
$lang['AdminMain.!success.domains_unparented'] = 'Os domínios selecionados foram removidos de seus serviços principais e o preço foi redefinido com sucesso!';
$lang['AdminMain.getfilters.field_service_meta'] = 'Nome de domínio';
$lang['AdminMain.getfilters.field_package_name'] = 'TLD';
$lang['AdminMain.getfilters.any'] = 'Qualquer';
$lang['AdminMain.domains.action.field_client'] = 'Cliente';
$lang['AdminMain.domains.action.field_nameservers'] = 'Servidores de nomes';
$lang['AdminMain.domains.action.field_years'] = 'Anos';
$lang['AdminMain.index.field_actionsubmit'] = 'Enviar';
$lang['AdminMain.index.domain_push_to_client'] = 'Enviar para o cliente';
$lang['AdminMain.index.update_nameservers'] = 'Atualizar servidores de nomes';
$lang['AdminMain.index.domain_renewal'] = 'Renovar domínio';
$lang['AdminMain.index.change_auto_renewal'] = 'Alterar renovação automática';
$lang['AdminMain.index.text_off'] = 'Desligado';
$lang['AdminMain.index.text_on'] = 'Em';
$lang['AdminMain.index.text_never'] = 'Nunca';
$lang['AdminMain.index.no_results'] = 'Não há serviços com esse status.';
$lang['AdminMain.index.confirm_delete'] = 'Tem certeza de que deseja excluir esse serviço?';
$lang['AdminMain.index.option_delete'] = 'Excluir';
$lang['AdminMain.index.option_manage'] = 'Gerenciar';
$lang['AdminMain.index.option_parent'] = 'Pais';
$lang['AdminMain.index.recurring_term'] = '%1$s %2$s @ %3$s';
$lang['AdminMain.index.categorylink_newservice'] = 'Novo domínio';
$lang['AdminMain.index.category_canceled'] = 'Cancelado';
$lang['AdminMain.index.category_suspended'] = 'Suspenso';
$lang['AdminMain.index.category_pending'] = 'Pendente';
$lang['AdminMain.index.category_active'] = 'Ativo';
$lang['AdminMain.index.heading_options'] = 'Opções';
$lang['AdminMain.index.heading_datecanceled'] = 'Data do cancelamento';
$lang['AdminMain.index.heading_datesuspended'] = 'Data da suspensão';
$lang['AdminMain.index.heading_dateexpires'] = 'Data de expiração';
$lang['AdminMain.index.heading_daterenews'] = 'Data de renovação';
$lang['AdminMain.index.heading_datecreated'] = 'Data de criação';
$lang['AdminMain.index.heading_term'] = 'Prazo';
$lang['AdminMain.index.heading_domain'] = 'Domínio';
$lang['AdminMain.index.heading_status'] = 'Status';
$lang['AdminMain.index.heading_addons'] = 'Complementos';
$lang['AdminMain.index.boxtitle_domains'] = 'Domínios';
$lang['AdminMain.index.page_title'] = 'Cliente #%1$s Domínios';
$lang['AdminMain.!success.domains_pushed'] = 'Os domínios selecionados foram enviados com sucesso para o novo cliente.';
$lang['AdminMain.!success.update_nameservers'] = 'Os servidores de nomes de domínio foram atualizados!';
$lang['AdminMain.!success.domain_renewal'] = 'O domínio foi renovado!';
$lang['AdminMain.!success.change_auto_renewal'] = 'A renovação automática do domínio foi atualizada!';
$lang['AdminMain.edit.text_registration_date'] = 'Data de registro:';
$lang['AdminMain.index.text_date_added'] = 'Data de adição:';
$lang['AdminMain.index.heading_dateregistration'] = 'Data de registro';
$lang['AdminMain.index.heading_registrar'] = 'Registrador';
$lang['AdminMain.!success.domain_registrar_updated'] = 'O registrador de domínios foi atualizado!';
$lang['AdminMain.edit.field_registration_date'] = 'Alterar data de registro';
$lang['AdminMain.edit.field_expiration_date'] = 'Alterar data de expiração';
$lang['AdminMain.!success.change_registration_date'] = 'A data de registro do domínio foi atualizada!';
$lang['AdminMain.!success.change_expiration_date'] = 'A data de expiração do domínio foi atualizada!';
